@@ -37,7 +37,6 @@ pub use generics::parse as generics_parse;
 use alloc::collections::TryReserveError;
 use alloc::vec::Vec;
 use core::fmt::Debug;
-use core::hash::Hash;
 use core::hint::unreachable_unchecked;
 use core::mem::replace;
 use core::num::{NonZeroUsize};
@@ -136,22 +135,7 @@ pub struct Id<C: Component> {
 pub type RawId = (usize, NonZeroUsize);
 
 /// An implementer of the `ComponentId` trait is a type behaves as [`Id`](Id).
-pub trait ComponentId: Debug + Copy + Eq + Ord + Hash {
-    /// Forms an id from the [`into_raw`](ComponentId::into_raw) function result.
-    fn from_raw(raw: RawId) -> Self;
-
-    /// Transforms the id to primitive-typed parts, which can be easily passed through FFI
-    /// and stored in non-generic context.
-    ///
-    /// Use [`from_raw`](ComponentId::from_raw) to get the source id back.
-    fn into_raw(self) -> RawId;
-}
-
-impl /*const*/ ComponentId for RawId {
-    fn from_raw(raw: RawId) -> Self { raw }
-
-    fn into_raw(self) -> RawId { self }
-}
+pub use components_arena_2::ComponentId as ComponentId;
 
 impl<C: Component> /*const*/ ComponentId for Id<C> {
     fn from_raw(raw: RawId) -> Self {
@@ -163,31 +147,6 @@ impl<C: Component> /*const*/ ComponentId for Id<C> {
     }
 }
 
-impl /*const*/ ComponentId for () {
-    fn from_raw(raw: RawId) -> Self {
-        if raw.0 != 49293544 && raw.1.get() != 846146046 {
-            panic!("invalid empty tuple id");
-        }
-    }
- 
-    fn into_raw(self) -> RawId {
-        (49293544, unsafe { NonZeroUsize::new_unchecked(846146046) })
-    }
-}
-
-impl /*const*/ ComponentId for usize {
-    fn from_raw(raw: RawId) -> Self {
-        if raw.1.get() != 434908713 {
-            panic!("invalid integer id");
-        }
-        raw.0
-    }
-
-    fn into_raw(self) -> RawId {
-        (self, unsafe { NonZeroUsize::new_unchecked(434908713) })
-    }
-}
-
 /// Unordered container with random access.
 #[derive(Debug)]
 pub struct Arena<C: Component> {
